#!/usr/bin/python
# -*- coding:utf-8 -*-

"""An abstract class of scoreboard classes.
"""

from dom import *
import scorecard
import re

def newInstance():
    return FIFA_2005()


class FIFA_2005( scorecard.ScoreCard ):
    def __init__( self ):
        scorecard.ScoreCard.__init__( self )
        return

    def getSportsCategory( self ):
        return "soccer"

    def getCountry( self ):
        return "World"

    def getName( self ):
        return "FIFA Men's Soccer (fifa.com)"

    def getVersion( self ):
        return "1.0"

    def getIcon( self, team ):
        nation = team.strip( '() \n\r\t' )
        import makelogo
        try:
            uri = makelogo.getURI( 'http://www.fifa.com//images/flags_large/flag_b_%s.gif' % nation, 'fifa', nation, transparency = None )
            return '<img src="%s" class="teamlogo" />' % uri
        except:
            raise
            return ''
        pass

    def getEncoding( self ):
        return 'iso-8859-1'

    def getLanguage( self ):
        return "en"

    def getURL( self ):
        return "http://www.fifa.com/en/mens/results/index.html"

    def applyFilter( self, contents ):
        return re.sub( '\"class=\"', '\" class=\"', contents )

    def __get_icon_src( self, href ):
        url = "http://www.fifa.com/" + href
        return '<img class="teamlogo" src="%s" />' % url

    def __resolve_game( self, elem_game ):
        result = elem_game.get_element_at_path( 'tr' )
        info   = elem_game.get_element_at_path( 'tr,4' )
        if result == None or info == None:
            return None
        #flag1 = result.get_element_at_path( 'td/a/img' )
        team1 = result.get_element_at_path( 'td,2' ).get_text( ' ' )
        score = result.get_element_at_path( 'td,3' ).get_first_child().get_text( ' ' )
        team2 = result.get_element_at_path( 'td,4' ).get_text( ' ' )
        import re
        m1 = ""
        m2 = ""
        m1 = re.search( '\([A-Z]+\)', team1 )
        if m1: icon1 = self.getIcon( m1.group( 0 ) )
        m2 = re.search( '\([A-Z]+\)', team2 )
        if m2: icon2 = self.getIcon( m2.group( 0 ) )
        #flag2 = result.get_element_at_path( 'td,5/a/img' )
        #print flag1
        #print flag2
        #icon1 = self.__get_icon_src( flag1.get_attribute( 'src' ) )
        #icon2 = self.__get_icon_src( flag2.get_attribute( 'src' ) )
        #print result
        title = info.get_text( ' ' )
        table = { 'title':title, 'data':( ( icon1, team1, score, team2, icon2 ), ) }
        #row = row.next_sibling( 'tr' )
        #print row.get_text( ',' )
        #row = row.next_sibling( 'tr' )
        #print row.get_text( ',' )
        
        #print row.get_text( ',' )
        return table

    def interpreteDocument( self, document ):
        import sys, re
        self.tables = []
        self.headerclasses = [ 'logo', 'team', 'score', 'team', 'logo' ]
        elem_game = document.get_element_at_path( '/html/table' )
        while elem_game != None:
            table = self.__resolve_game( elem_game )
            if table: self.tables.append( table )
            #self.tables.append( table )
            #print elem_game.get_text( ',' )
            try:
                elem_game = elem_game.next_sibling( 'table')
            except:
                break
            pass
        #print document
        pass
    
    #def getIgnorableTags( self ):
    #return [ 'span', 'script' ]

    def getStartKeyword( self ):
        return "<!--Previous Next Bar end-->"

    def getEndKeyword( self ):
        return "<!--Previous Next Bar start-->"

    def toHTML( self ):
        """Format data into HTML.
        This method must be overridden."""
        html  = self.html_header()
        if len( self.tables ) == 0:
            html += self.html_footer()
            return html
        for table in self.tables:
            try:
                title = table[ 'title' ]
                rows = table[ 'data' ]
                html += '<span class="tabletitle">%s</span>\n' % title
                html += '<table>\n'
                for row in rows:
                    html += '<tr>'
                    for i in range( min( len( self.headerclasses ), len( row ) ) ):
                        html += '<td class="%s">%s</td>' % ( self.headerclasses[ i ], row[ i ] )
                        pass
                    html += '</tr>\n'
                    pass
                html += '</table>\n'
            except:
                pass
            pass
        html += self.html_footer()
        return html

    def html_css_plugin( self ):
        return """
        <style type=\"text/css\">
        table { margin-bottom:10px; }
        .teamlogo {width:32;}
        .tabletitle {font-size:8px; font-weight:normal;}
        </style>
        """

    __nation_codes = {
                "Afghanistan":"AFG","Albania":"ALB",
                "Algeria":"ALG","American Samoa":"ASA",
                "Andorra":"AND","Angola":"ANG","Anguilla":"AIA",
                "Antigua and Barbuda":"ATG","Argentina":"ARG",
                "Armenia":"ARM","Aruba":"ARU","Australia":"AUS",
                "Austria":"AUT","Azerbaijan":"AZE","Bahamas":"BAH",
                "Bahrain":"BHR","Bangladesh":"BAN","Barbados":"BRB",
                "Belarus":"BLR","Belgium":"BEL","Belize":"BLZ",
                "Benin":"BEN","Bermuda":"BER","Bhutan":"BHU",
                "Bolivia":"BOL","Bosnia-Herzegovina":"BIH",
                "Botswana":"BOT","Brazil":"BRA",
                "British Virgin Islands":"VGB",
                "Brunei Darussalam":"BRU","Bulgaria":"BUL",
                "Burkina Faso":"BFA","Burundi":"BDI",
                "Cambodia":"CAM","Cameroon":"CMR","Canada":"CAN",
                "Cape Verde Islands":"CPV","Cayman Islands":"CAY",
                "Central African Republic":"CTA","Chad":"CHA",
                "Chile":"CHI","China PR":"CHN",
                "Chinese Taipei":"TPE","Colombia":"COL",
                "Congo":"CGO","Congo DR":"COD","Cook Islands":"COK",
                "Costa Rica":"CRC","Croatia":"CRO","Cuba":"CUB",
                "Cyprus":"CYP","Czech Republic":"CZE",
                "Côte d'Ivoire":"CIV","Denmark":"DEN",
                "Djibouti":"DJI","Dominica":"DMA",
                "Dominican Republic":"DOM","Ecuador":"ECU",
                "Egypt":"EGY","El Salvador":"SLV","England":"ENG",
                "Equatorial Guinea":"EQG","Eritrea":"ERI",
                "Estonia":"EST","Ethiopia":"ETH",
                "FYR Macedonia":"MKD","Faroe Islands":"FRO",
                "Fiji":"FIJ","Finland":"FIN","France":"FRA",
                "Gabon":"GAB","Gambia":"GAM","Georgia":"GEO",
                "Germany":"GER","Ghana":"GHA","Greece":"GRE",
                "Grenada":"GRN","Guam":"GUM","Guatemala":"GUA",
                "Guinea":"GUI","Guinea-Bissau":"GNB","Guyana":"GUY",
                "Haiti":"HAI","Honduras":"HON","Hong Kong":"HKG",
                "Hungary":"HUN","Iceland":"ISL","India":"IND",
                "Indonesia":"IDN","Iran":"IRN","Iraq":"IRQ",
                "Israel":"ISR","Italy":"ITA","Jamaica":"JAM",
                "Japan":"JPN","Jordan":"JOR","Kazakhstan":"KAZ",
                "Kenya":"KEN","Korea DPR":"PRK",
                "Korea Republic":"KOR","Kuwait":"KUW",
                "Kyrgyzstan":"KGZ","Laos":"LAO","Latvia":"LVA",
                "Lebanon":"LIB","Lesotho":"LES","Liberia":"LBR",
                "Libya":"LBY","Liechtenstein":"LIE",
                "Lithuania":"LTU","Luxembourg":"LUX","Macao":"MAC",
                "Madagascar":"MAD","Malawi":"MWI","Malaysia":"MAS",
                "Maldives":"MDV","Mali":"MLI","Malta":"MLT",
                "Mauritania":"MTN","Mauritius":"MRI","Mexico":"MEX",
                "Moldova":"MDA","Mongolia":"MGL","Montserrat":"MSR",
                "Morocco":"MAR","Mozambique":"MOZ","Myanmar":"MYA",
                "Namibia":"NAM","Nepal":"NEP","Netherlands":"NED",
                "Netherlands Antilles":"ANT","New Caledonia":"NCL",
                "New Zealand":"NZL","Nicaragua":"NCA","Niger":"NIG",
                "Nigeria":"NGA","Northern Ireland":"NIR",
                "Norway":"NOR","Oman":"OMA","Pakistan":"PAK",
                "Palestine":"PAL","Panama":"PAN",
                "Papua New Guinea":"PNG","Paraguay":"PAR",
                "Peru":"PER","Philippines":"PHI","Poland":"POL",
                "Portugal":"POR","Puerto Rico":"PUR","Qatar":"QAT",
                "Republic of Ireland":"IRL","Romania":"ROU",
                "Russia":"RUS","Rwanda":"RWA","Samoa":"SAM",
                "San Marino":"SMR","Saudi Arabia":"KSA",
                "Scotland":"SCO","Senegal":"SEN",
                "Serbia and Montenegro":"SCG","Seychelles":"SEY",
                "Sierra Leone":"SLE","Singapore":"SIN",
                "Slovakia":"SVK","Slovenia":"SVN",
                "Solomon Islands":"SOL","Somalia":"SOM",
                "South Africa":"RSA","Spain":"ESP",
                "Sri Lanka":"SRI","St. Kitts and Nevis":"SKN",
                "St. Lucia":"LCA",
                "St. Vincent and the Grenadines":"VIN",
                "Sudan":"SUD","Surinam":"SUR","Swaziland":"SWZ",
                "Sweden":"SWE","Switzerland":"SUI","Syria":"SYR",
                "São Tomé e Príncipe":"STP","Tahiti":"TAH",
                "Tajikistan":"TJK","Tanzania":"TAN",
                "Thailand":"THA","Togo":"TOG","Tonga":"TGA",
                "Trinidad and Tobago":"TRI","Tunisia":"TUN",
                "Turkey":"TUR","Turkmenistan":"TKM",
                "Turks and Caicos Islands":"TCA",
                "US Virgin Islands":"VIR","USA":"USA",
                "Uganda":"UGA","Ukraine":"UKR",
                "United Arab Emirates":"UAE","Uruguay":"URU",
                "Uzbekistan":"UZB","Vanuatu":"VAN",
                "Venezuela":"VEN","Vietnam":"VIE","Wales":"WAL",
                "Yemen":"YEM","Zambia":"ZAM","Zimbabwe":"ZIM" }

    def __get_nation_code( self, nation ):
        if self.__nation_codes.has_key( nation ):
            return self.__nation_codes[ nation ]
        return nation

    get_nation_code = classmethod( __get_nation_code )
    
    pass

#global __nations
#__nations = None
def get_nation_code( nation ):
    return FIFA_2005.get_nation_code( nation )

if __name__ == "__main__":
    import sys
    import tempfile
    from dom import *

    skin = None
    filename_input = None

    obj = newInstance()
    if len( sys.argv ) > 1: filename_input = sys.argv[ 1 ]
    
    if obj == None or obj.isAvailable() == False:
        print "invalid object"
        sys.exit()

    url = obj.getURL()
    encoding = obj.getEncoding()
    if filename_input:
        data = ""
        for line in open( filename_input ).readlines():
            data += line
            pass
        pass
    else:
        data = loadHTML( url, encoding )
        pass
    kw_start = obj.getStartKeyword()
    kw_end   = obj.getEndKeyword()
    parser = DOMConverter()
    for tag in obj.getIgnorableTags():
        parser.add_ignoring_tag( tag )
        pass
    if kw_start == None or kw_end == None:
        if encoding == None:
            parser.feed( obj.decode( obj.applyFilter( data ) ) )
        else:
            for line in data.split( "\n" ):
                parser.feed( obj.applyFilter( line ) )
                pass
            pass
        pass
    else:
        flag_inside = False
        parser.feed( '<html>' )
        for line in re.split( "\n", data ):
            line = obj.applyFilter( line )
            if encoding == None:
                line = obj.decode( line.strip() )
                pass
            if flag_inside:
                if line.count( kw_end ) > 0:
                    flag_inside = False
                    break
                else:
                    parser.feed( line )
                    pass
            elif line.count( kw_start ) > 0: flag_inside = True
            pass
        parser.feed( '</html>' )
        pass
    document = parser.get_document()
    obj.interpreteDocument( document )
    contents = obj.toHTML()
    print contents
